@@ -19,7 +19,7 @@ use strict;
 use warnings;
 
 use Spreadsheet::ParseExcel::Utility qw(ExcelFmt);
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 my %hFmtDefault = (
     0x00 => '@',
@@ -28,9 +28,9 @@ my %hFmtDefault = (
     0x03 => '#,##0',
     0x04 => '#,##0.00',
     0x05 => '($#,##0_);($#,##0)',
-    0x06 => '($#,##0_);[RED]($#,##0)',
+    0x06 => '($#,##0_);[Red]($#,##0)',
     0x07 => '($#,##0.00_);($#,##0.00_)',
-    0x08 => '($#,##0.00_);[RED]($#,##0.00_)',
+    0x08 => '($#,##0.00_);[Red]($#,##0.00_)',
     0x09 => '0%',
     0x0A => '0.00%',
     0x0B => '0.00E+00',
@@ -48,9 +48,9 @@ my %hFmtDefault = (
 
     #0x17-0x24 -- Differs in Natinal
     0x25 => '(#,##0_);(#,##0)',
-    0x26 => '(#,##0_);[RED](#,##0)',
+    0x26 => '(#,##0_);[Red](#,##0)',
     0x27 => '(#,##0.00);(#,##0.00)',
-    0x28 => '(#,##0.00);[RED](#,##0.00)',
+    0x28 => '(#,##0.00);[Red](#,##0.00)',
     0x29 => '_(*#,##0_);_(*(#,##0);_(*"-"_);_(@_)',
     0x2A => '_($*#,##0_);_($*(#,##0);_(*"-"_);_(@_)',
     0x2B => '_(*#,##0.00_);_(*(#,##0.00);_(*"-"??_);_(@_)',
