@@ -21,7 +21,7 @@ use warnings;
 
 use Encode qw(find_encoding decode);
 use base 'Spreadsheet::ParseExcel::FmtDefault';
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 my %FormatTable = (
     0x00 => '@',
@@ -30,9 +30,9 @@ my %FormatTable = (
     0x03 => '#,##0',
     0x04 => '#,##0.00',
     0x05 => '(\\#,##0_);(\\#,##0)',
-    0x06 => '(\\#,##0_);[RED](\\#,##0)',
+    0x06 => '(\\#,##0_);[Red](\\#,##0)',
     0x07 => '(\\#,##0.00_);(\\#,##0.00_)',
-    0x08 => '(\\#,##0.00_);[RED](\\#,##0.00_)',
+    0x08 => '(\\#,##0.00_);[Red](\\#,##0.00_)',
     0x09 => '0%',
     0x0A => '0.00%',
     0x0B => '0.00E+00',
@@ -60,9 +60,9 @@ my %FormatTable = (
 
     #0x17-0x24 -- Differs in Natinal
     0x25 => '(#,##0_);(#,##0)',
-    0x26 => '(#,##0_);[RED](#,##0)',
+    0x26 => '(#,##0_);[Red](#,##0)',
     0x27 => '(#,##0.00);(#,##0.00)',
-    0x28 => '(#,##0.00);[RED](#,##0.00)',
+    0x28 => '(#,##0.00);[Red](#,##0.00)',
     0x29 => '_(*#,##0_);_(*(#,##0);_(*"-"_);_(@_)',
     0x2A => '_(\\*#,##0_);_(\\*(#,##0);_(*"-"_);_(@_)',
     0x2B => '_(*#,##0.00_);_(*(#,##0.00);_(*"-"??_);_(@_)',
