@@ -18,7 +18,7 @@ package Spreadsheet::ParseExcel::Workbook;
 use strict;
 use warnings;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 ###############################################################################
 #
@@ -32,6 +32,14 @@ sub new {
     bless $self, $class;
 }
 
+###############################################################################
+sub color_idx_to_rgb {
+    my( $workbook, $iidx ) = @_;
+
+    my $palette = $workbook->{aColor};
+    return ( ( defined $palette->[$iidx] ) ? $palette->[$iidx] : $palette->[0] );
+}
+
 ###############################################################################
 #
 # worksheet()
@@ -142,6 +150,19 @@ sub ParseAbort {
     $self->{_ParseAbort} = $val;
 }
 
+=head2 get_active_sheet()
+
+Return the number of the active (open) worksheet (at the time the workbook
+was saved.  May return undef.
+
+=cut
+
+sub get_active_sheet {
+    my $workbook = shift;
+
+    return $workbook->{ActiveSheet};
+}
+
 ###############################################################################
 #
 # Parse(). Deprecated.
